@@ -170,7 +170,14 @@ module Lumberjack
     def format(message)
       formatter = formatter_for(message.class)
       if formatter&.respond_to?(:call)
-        formatter.call(message)
+        begin
+          formatter.call(message)
+        rescue SystemStackError, StandardError => e
+          error_message = e.class.name
+          error_message = "#{error_message} #{e.message}" if e.message && e.message != ""
+          warn("<Error formatting #{message.class.name}: #{error_message}>")
+          "<Error formatting #{message.class.name}: #{error_message}>"
+        end
       else
         message
       end
